@@ -100,7 +100,7 @@ bool VulkanFunctions::Validate() const {
            this->CreateInstance != nullptr && this->DestroyInstance != nullptr && this->GetPhysicalDeviceProperties2 != nullptr;
 }
 
-static VkResult CreateInstance(const VulkanFunctions &vk, bool enumerate_portability, VkInstance &instance) {
+static VkResult CreateInstance(const VulkanFunctions &vk, VkInstance &instance) {
     uint32_t property_count = 0;
     VkResult err = vk.EnumerateInstanceExtensionProperties(nullptr, &property_count, nullptr);
     assert(err == VK_SUCCESS);
@@ -112,17 +112,16 @@ static VkResult CreateInstance(const VulkanFunctions &vk, bool enumerate_portabi
     // Handle Portability Enumeration requirements
     std::vector<const char *> instance_extensions;
 
+    bool enumerate_portability = false;
     for (std::size_t i = 0, n = instance_properties.size(); i < n; ++i) {
         if (instance_properties[i].extensionName == std::string(VK_KHR_EXTERNAL_MEMORY_CAPABILITIES_EXTENSION_NAME)) {
             instance_extensions.push_back(VK_KHR_EXTERNAL_MEMORY_CAPABILITIES_EXTENSION_NAME);
         }
-#if VK_KHR_portability_enumeration
-        if (enumerate_portability) {
-            if (instance_properties[i].extensionName == std::string(VK_KHR_PORTABILITY_ENUMERATION_EXTENSION_NAME)) {
-                instance_extensions.push_back(VK_KHR_PORTABILITY_ENUMERATION_EXTENSION_NAME);
-            }
+
+        if (instance_properties[i].extensionName == std::string(VK_KHR_PORTABILITY_ENUMERATION_EXTENSION_NAME)) {
+            instance_extensions.push_back(VK_KHR_PORTABILITY_ENUMERATION_EXTENSION_NAME);
+            enumerate_portability = true;
         }
-#endif
     }
 
     // Check Vulkan Devices
@@ -138,11 +137,11 @@ static VkResult CreateInstance(const VulkanFunctions &vk, bool enumerate_portabi
 
     VkInstanceCreateInfo inst_info = {};
     inst_info.sType = VK_STRUCTURE_TYPE_INSTANCE_CREATE_INFO;
-#if VK_KHR_portability_enumeration
+
     if (enumerate_portability) {
         inst_info.flags = VK_INSTANCE_CREATE_ENUMERATE_PORTABILITY_BIT_KHR;
     }
-#endif
+
     inst_info.pNext = nullptr;
     inst_info.pApplicationInfo = &app;
     inst_info.enabledLayerCount = 0;
@@ -153,6 +152,30 @@ static VkResult CreateInstance(const VulkanFunctions &vk, bool enumerate_portabi
     return vk.CreateInstance(&inst_info, nullptr, &instance);
 }
 
+std::string DeviceInfo::GetLabel() const {
+    if (this->driverName.empty()) {
+        return this->deviceName;
+    }
+
+    if (this->deviceName.find(this->driverName) != std::string::npos) {
+        return this->deviceName;
+    }
+
+    return this->driverName + " " + this->deviceName;
+}
+
+std::string VulkanPhysicalDeviceInfo::GetLabel() const {
+    if (this->driverName.empty()) {
+        return this->deviceName;
+    }
+
+    if (this->deviceName.find(this->driverName) != std::string::npos) {
+        return this->deviceName;
+    }
+
+    return this->driverName + " " + this->deviceName;
+}
+
 std::string VulkanPhysicalDeviceInfo::GetVersion() const {
     if (this->vendorID == 0x10DE) {
         return FormatNvidia(this->driverVersion);
@@ -167,6 +190,7 @@ DeviceInfo GetDeviceInfo(const VulkanPhysicalDeviceInfo &info) {
     DeviceInfo device_info;
     device_info.deviceName = info.deviceName;
     std::copy(std::begin(info.deviceUUID), std::end(info.deviceUUID), std::begin(device_info.deviceUUID));
+    device_info.driverName = info.driverName;
     device_info.driverVersion = info.driverVersion;
     return device_info;
 }
@@ -207,17 +231,21 @@ VulkanSystemInfo BuildVulkanSystemInfo() {
     std::uint32_t instance_layer_count = 0;
     result = vk.EnumerateInstanceLayerProperties(&instance_layer_count, nullptr);
     assert(result == VK_SUCCESS);
-    vulkan_system_info.instanceLayerProperties.resize(instance_layer_count);
-    result = vk.EnumerateInstanceLayerProperties(&instance_layer_count, vulkan_system_info.instanceLayerProperties.data());
-    assert(result == VK_SUCCESS);
+    if (instance_layer_count > 0) {
+        vulkan_system_info.instanceLayerProperties.resize(instance_layer_count);
+        result = vk.EnumerateInstanceLayerProperties(&instance_layer_count, vulkan_system_info.instanceLayerProperties.data());
+        assert(result == VK_SUCCESS);
+    }
 
     uint32_t instance_extension_count = 0;
     result = vk.EnumerateInstanceExtensionProperties(nullptr, &instance_extension_count, nullptr);
     assert(result == VK_SUCCESS);
-    vulkan_system_info.instanceExtensionPropertie.resize(instance_extension_count);
-    result = vk.EnumerateInstanceExtensionProperties(nullptr, &instance_extension_count,
-                                                     vulkan_system_info.instanceExtensionPropertie.data());
-    assert(result == VK_SUCCESS);
+    if (instance_extension_count > 0) {
+        vulkan_system_info.instanceExtensionPropertie.resize(instance_extension_count);
+        result = vk.EnumerateInstanceExtensionProperties(nullptr, &instance_extension_count,
+                                                         vulkan_system_info.instanceExtensionPropertie.data());
+        assert(result == VK_SUCCESS);
+    }
 
     // Handle Portability Enumeration requirements
     std::vector<const char *> instance_extensions;
@@ -275,12 +303,15 @@ VulkanSystemInfo BuildVulkanSystemInfo() {
     for (std::size_t i = 0, n = devices.size(); i < n; ++i) {
         VulkanPhysicalDeviceInfo &device_info = vulkan_system_info.physicalDevices[i];
 
-        VkPhysicalDeviceIDPropertiesKHR properties_deviceid{VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_ID_PROPERTIES_KHR, nullptr};
+        VkPhysicalDeviceDriverPropertiesKHR properties_driver{VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_DRIVER_PROPERTIES_KHR, nullptr};
+        VkPhysicalDeviceIDPropertiesKHR properties_deviceid{VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_ID_PROPERTIES_KHR,
+                                                            &properties_driver};
         VkPhysicalDeviceProperties2 properties2{VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_PROPERTIES_2, &properties_deviceid};
 
         vk.GetPhysicalDeviceProperties2(devices[i], &properties2);
 
         device_info.deviceName = properties2.properties.deviceName;
+        device_info.driverName = properties_driver.driverName;
 
         /* For multiple driver version testing only
                 if (device_info.deviceName.find("llvmpipe") != std::string::npos) {
@@ -484,12 +515,9 @@ std::string GenerateLoaderLog() {
     if (vk.Validate()) {
         VkInstance instance = VK_NULL_HANDLE;
 
-        VkResult err = ::CreateInstance(vk, false, instance);
+        VkResult err = ::CreateInstance(vk, instance);
         if (err == VK_ERROR_INCOMPATIBLE_DRIVER) {
-            err = ::CreateInstance(vk, true, instance);
-            if (err == VK_ERROR_INCOMPATIBLE_DRIVER) {
-                return "VK_ERROR_INCOMPATIBLE_DRIVER\n";
-            }
+            return "VK_ERROR_INCOMPATIBLE_DRIVER\n";
         }
         vk.DestroyInstance(instance, nullptr);
     }
